==> basic_ui-0.1.0.tar.gz: lib/src/widgets/basic_list_view.dart <==
import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';

/// Creates a fixed-length scrollable linear array of list "items" separated
/// by [Divider].
///
/// This Widget is appropriate for list views with a large number of item
/// and separator children because the builders are only called for the children
/// that are actually visible.
class BasicListView extends HookWidget {
  const BasicListView({
    Key? key,
    required this.itemCount,
    required this.itemBuilder,
    this.disableDivider = false,
    this.padding,
  }) : super(key: key);

  /// Number of items in list view.
  final int itemCount;

  /// Build Widget to display in list view.
  final Widget Function(BuildContext, int) itemBuilder;

  /// Set to true to disable divider.
  final bool disableDivider;

  /// The empty space that surrounds the list view.
  final EdgeInsetsGeometry? padding;

  @override
  Widget build(BuildContext context) {
    final theme = useProvider(themeProvider).theme;

    if (!disableDivider) {
      return ListView.separated(
        padding: padding,
        itemCount: itemCount,
        itemBuilder: itemBuilder,
        separatorBuilder: (context, index) {
          return Divider(color: theme.borderColor);
        },
      );
    }
    return ListView.builder(
      padding: padding,
      itemCount: itemCount,
      itemBuilder: itemBuilder,
    );
  }
}

==> basic_ui-0.2.2.tar.gz: lib/src/widgets/basic_list_view.dart <==
import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';

/// Creates a fixed-length scrollable linear array of list "items" separated
/// by [Divider].
///
/// This Widget is appropriate for list views with a large number of item
/// and separator children because the builders are only called for the children
/// that are actually visible.
class BasicListView extends HookWidget {
  const BasicListView({
    Key? key,
    required this.itemCount,
    required this.itemBuilder,
    this.enableDivider = false,
    this.padding,
    this.reverse = false,
    this.controller,
    this.physics,
  }) : super(key: key);

  /// Number of items in list view.
  final int itemCount;

  /// Build Widget to display in list view.
  final Widget Function(BuildContext, int) itemBuilder;

  /// Set to true to enable divider.
  final bool enableDivider;

  /// The empty space that surrounds the list view.
  final EdgeInsetsGeometry? padding;

  /// If true list will be reverse.
  final bool reverse;

  /// Controller for scroll container.
  final ScrollController? controller;

  /// Determines the physics of a [Scrollable] widget.
  final ScrollPhysics? physics;

  @override
  Widget build(BuildContext context) {
    final theme = useProvider(themeProvider).theme;

    if (enableDivider) {
      return ListView.separated(
        controller: controller,
        padding: padding,
        itemCount: itemCount,
        itemBuilder: itemBuilder,
        separatorBuilder: (context, index) {
          return Divider(color: theme.borderColor);
        },
      );
    }
    return ListView.builder(
      physics: physics,
      controller: controller,
      reverse: reverse,
      padding: padding,
      itemCount: itemCount,
      itemBuilder: itemBuilder,
    );
  }
}
